import * as SourceMapSupport from "source-map-support";
import * as PrettyError from "pretty-error";
import { app } from "electron";
import Window from "./window";

export default class Boot
{
    private static window: Window;
    private static isBooted: boolean = false;

    public static init(): void
    {
        if (Boot.isBooted === true) {
            throw new Error("Application is already booted.");
        }
        Boot.overloadErrorStack();
        Boot.initWindow();
        Boot.attachAppEventHandlers();
        Boot.isBooted = true;
    }

    private static overloadErrorStack(): void
    {
        SourceMapSupport.install();
        let prettyError: PrettyError = new PrettyError();
        prettyError.withoutColors();
        prettyError.skipNodeFiles();
        prettyError.skipPackage("electron");
        prettyError.start();
    }

    private static initWindow(): void
    {
        this.window = new Window();
    }

    private static attachAppEventHandlers(): void
    {
        app.on("ready", () => {
            this.window.init();
        });
        app.on("activate", () => {
            this.window.init();
        });
        app.on("window-all-closed", () => {
            if (process.platform !== "darwin") {
                app.quit()
            }
        });
    }
}